pub struct DeploymentConfig {
pub metadata: ObjectMeta,
pub spec: DeploymentConfigSpec,
pub status: Option<DeploymentConfigStatus>,
}Expand description
Deployment Configs define the template for a pod and manages deploying new images or configuration changes. A single deployment configuration is usually analogous to a single micro-service. Can support many different deployment patterns, including full restart, customizable rolling updates, and fully custom behaviors, as well as pre- and post- deployment hooks. Each individual deployment is represented as a replication controller.
A deployment is “triggered” when its configuration is changed or a tag in an Image Stream is changed. Triggers can be disabled to allow manual control over a deployment. The “strategy” determines how the deployment is carried out and may be changed at any time. The latestVersion field is updated when a new deployment is triggered by any means.
Fields
metadata: ObjectMetaStandard object’s metadata.
spec: DeploymentConfigSpecSpec represents a desired deployment state and how to deploy to it.
status: Option<DeploymentConfigStatus>Status represents the current deployment state.
Implementations
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn create_namespaced_deployment_config(
namespace: &str,
body: &DeploymentConfig,
optional: CreateOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
pub fn create_namespaced_deployment_config( namespace: &str, body: &DeploymentConfig, optional: CreateOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
create a DeploymentConfig
Use the returned k8s_openapi::ResponseBody<k8s_openapi::CreateResponse<Self>> constructor, or k8s_openapi::CreateResponse<Self> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn delete_collection_namespaced_deployment_config(
namespace: &str,
delete_optional: DeleteOptional<'_>,
list_optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
pub fn delete_collection_namespaced_deployment_config( namespace: &str, delete_optional: DeleteOptional<'_>, list_optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
delete collection of DeploymentConfig
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<k8s_openapi::List<Self>>> constructor, or k8s_openapi::DeleteResponse<k8s_openapi::List<Self>> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
delete_optionalDelete options. Use
Default::default()to not pass any. -
list_optionalList options. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn delete_namespaced_deployment_config(
name: &str,
namespace: &str,
optional: DeleteOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
pub fn delete_namespaced_deployment_config( name: &str, namespace: &str, optional: DeleteOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
delete a DeploymentConfig
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<Self>> constructor, or k8s_openapi::DeleteResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the DeploymentConfig
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn list_deployment_config_for_all_namespaces(
optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list_deployment_config_for_all_namespaces( optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind DeploymentConfig
This operation only supports listing all items of this type.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ListResponse<Self>> constructor, or k8s_openapi::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn list_namespaced_deployment_config(
namespace: &str,
optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list_namespaced_deployment_config( namespace: &str, optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind DeploymentConfig
This operation only supports listing all items of this type.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ListResponse<Self>> constructor, or k8s_openapi::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn patch_namespaced_deployment_config(
name: &str,
namespace: &str,
body: &Patch,
optional: PatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_namespaced_deployment_config( name: &str, namespace: &str, body: &Patch, optional: PatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update the specified DeploymentConfig
Use the returned k8s_openapi::ResponseBody<k8s_openapi::PatchResponse<Self>> constructor, or k8s_openapi::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the DeploymentConfig
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn patch_namespaced_deployment_config_status(
name: &str,
namespace: &str,
body: &Patch,
optional: PatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_namespaced_deployment_config_status( name: &str, namespace: &str, body: &Patch, optional: PatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update status of the specified DeploymentConfig
Use the returned k8s_openapi::ResponseBody<k8s_openapi::PatchResponse<Self>> constructor, or k8s_openapi::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the DeploymentConfig
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn read_namespaced_deployment_config(
name: &str,
namespace: &str,
optional: ReadNamespacedDeploymentConfigOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedDeploymentConfigResponse>), RequestError>
pub fn read_namespaced_deployment_config( name: &str, namespace: &str, optional: ReadNamespacedDeploymentConfigOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedDeploymentConfigResponse>), RequestError>
read the specified DeploymentConfig
Use the returned k8s_openapi::ResponseBody<ReadNamespacedDeploymentConfigResponse> constructor, or ReadNamespacedDeploymentConfigResponse directly, to parse the HTTP response.
Arguments
-
namename of the DeploymentConfig
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn read_namespaced_deployment_config_status(
name: &str,
namespace: &str,
optional: ReadNamespacedDeploymentConfigStatusOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedDeploymentConfigStatusResponse>), RequestError>
pub fn read_namespaced_deployment_config_status( name: &str, namespace: &str, optional: ReadNamespacedDeploymentConfigStatusOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedDeploymentConfigStatusResponse>), RequestError>
read status of the specified DeploymentConfig
Use the returned k8s_openapi::ResponseBody<ReadNamespacedDeploymentConfigStatusResponse> constructor, or ReadNamespacedDeploymentConfigStatusResponse directly, to parse the HTTP response.
Arguments
-
namename of the DeploymentConfig
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn replace_namespaced_deployment_config(
name: &str,
namespace: &str,
body: &DeploymentConfig,
optional: ReplaceOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_namespaced_deployment_config( name: &str, namespace: &str, body: &DeploymentConfig, optional: ReplaceOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace the specified DeploymentConfig
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ReplaceResponse<Self>> constructor, or k8s_openapi::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the DeploymentConfig
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn replace_namespaced_deployment_config_status(
name: &str,
namespace: &str,
body: &DeploymentConfig,
optional: ReplaceOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_namespaced_deployment_config_status( name: &str, namespace: &str, body: &DeploymentConfig, optional: ReplaceOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace status of the specified DeploymentConfig
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ReplaceResponse<Self>> constructor, or k8s_openapi::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the DeploymentConfig
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn watch_deployment_config_for_all_namespaces(
optional: WatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch_deployment_config_for_all_namespaces( optional: WatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind DeploymentConfig
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::WatchResponse<Self>> constructor, or k8s_openapi::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl DeploymentConfig
impl DeploymentConfig
Sourcepub fn watch_namespaced_deployment_config(
namespace: &str,
optional: WatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch_namespaced_deployment_config( namespace: &str, optional: WatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind DeploymentConfig
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::WatchResponse<Self>> constructor, or k8s_openapi::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.