pub struct DeploymentConfigStatus {
pub available_replicas: i32,
pub conditions: Option<Vec<DeploymentCondition>>,
pub details: Option<DeploymentDetails>,
pub latest_version: i64,
pub observed_generation: i64,
pub ready_replicas: Option<i32>,
pub replicas: i32,
pub unavailable_replicas: i32,
pub updated_replicas: i32,
}Expand description
DeploymentConfigStatus represents the current deployment state.
Fields
available_replicas: i32AvailableReplicas is the total number of available pods targeted by this deployment config.
conditions: Option<Vec<DeploymentCondition>>Conditions represents the latest available observations of a deployment config’s current state.
details: Option<DeploymentDetails>Details are the reasons for the update to this deployment config. This could be based on a change made by the user or caused by an automatic trigger
latest_version: i64LatestVersion is used to determine whether the current deployment associated with a deployment config is out of sync.
observed_generation: i64ObservedGeneration is the most recent generation observed by the deployment config controller.
ready_replicas: Option<i32>Total number of ready pods targeted by this deployment.
replicas: i32Replicas is the total number of pods targeted by this deployment config.
UnavailableReplicas is the total number of unavailable pods targeted by this deployment config.
updated_replicas: i32UpdatedReplicas is the total number of non-terminated pods targeted by this deployment config that have the desired template spec.