pub struct DeploymentStrategy {
pub active_deadline_seconds: Option<i64>,
pub annotations: Option<BTreeMap<String, String>>,
pub custom_params: Option<CustomDeploymentStrategyParams>,
pub labels: Option<BTreeMap<String, String>>,
pub recreate_params: Option<RecreateDeploymentStrategyParams>,
pub resources: Option<ResourceRequirements>,
pub rolling_params: Option<RollingDeploymentStrategyParams>,
pub type_: Option<String>,
}Expand description
DeploymentStrategy describes how to perform a deployment.
Fields
active_deadline_seconds: Option<i64>ActiveDeadlineSeconds is the duration in seconds that the deployer pods for this deployment config may be active on a node before the system actively tries to terminate them.
annotations: Option<BTreeMap<String, String>>Annotations is a set of key, value pairs added to custom deployer and lifecycle pre/post hook pods.
custom_params: Option<CustomDeploymentStrategyParams>CustomParams are the input to the Custom deployment strategy, and may also be specified for the Recreate and Rolling strategies to customize the execution process that runs the deployment.
labels: Option<BTreeMap<String, String>>Labels is a set of key, value pairs added to custom deployer and lifecycle pre/post hook pods.
recreate_params: Option<RecreateDeploymentStrategyParams>RecreateParams are the input to the Recreate deployment strategy.
resources: Option<ResourceRequirements>Resources contains resource requirements to execute the deployment and any hooks.
rolling_params: Option<RollingDeploymentStrategyParams>RollingParams are the input to the Rolling deployment strategy.
type_: Option<String>Type is the name of a deployment strategy.