pub struct ImageStream {
pub metadata: ObjectMeta,
pub spec: ImageStreamSpec,
pub status: Option<ImageStreamStatus>,
}Expand description
ImageStream stores a mapping of tags to images, metadata overrides that are applied when images are tagged in a stream, and an optional reference to a container image repository on a registry.
Fields
metadata: ObjectMetaStandard object’s metadata.
spec: ImageStreamSpecSpec describes the desired state of this stream
status: Option<ImageStreamStatus>Status describes the current state of this stream
Implementations
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn create_namespaced_image_stream(
namespace: &str,
body: &ImageStream,
optional: CreateOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
pub fn create_namespaced_image_stream( namespace: &str, body: &ImageStream, optional: CreateOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
create an ImageStream
Use the returned k8s_openapi::ResponseBody<k8s_openapi::CreateResponse<Self>> constructor, or k8s_openapi::CreateResponse<Self> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn delete_collection_namespaced_image_stream(
namespace: &str,
delete_optional: DeleteOptional<'_>,
list_optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
pub fn delete_collection_namespaced_image_stream( namespace: &str, delete_optional: DeleteOptional<'_>, list_optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
delete collection of ImageStream
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<k8s_openapi::List<Self>>> constructor, or k8s_openapi::DeleteResponse<k8s_openapi::List<Self>> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
delete_optionalDelete options. Use
Default::default()to not pass any. -
list_optionalList options. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn delete_namespaced_image_stream(
name: &str,
namespace: &str,
optional: DeleteOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
pub fn delete_namespaced_image_stream( name: &str, namespace: &str, optional: DeleteOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
delete an ImageStream
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<Self>> constructor, or k8s_openapi::DeleteResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the ImageStream
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn list_image_stream_for_all_namespaces(
optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list_image_stream_for_all_namespaces( optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind ImageStream
This operation only supports listing all items of this type.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ListResponse<Self>> constructor, or k8s_openapi::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn list_namespaced_image_stream(
namespace: &str,
optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list_namespaced_image_stream( namespace: &str, optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind ImageStream
This operation only supports listing all items of this type.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ListResponse<Self>> constructor, or k8s_openapi::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn patch_namespaced_image_stream(
name: &str,
namespace: &str,
body: &Patch,
optional: PatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_namespaced_image_stream( name: &str, namespace: &str, body: &Patch, optional: PatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update the specified ImageStream
Use the returned k8s_openapi::ResponseBody<k8s_openapi::PatchResponse<Self>> constructor, or k8s_openapi::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the ImageStream
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn patch_namespaced_image_stream_status(
name: &str,
namespace: &str,
body: &Patch,
optional: PatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_namespaced_image_stream_status( name: &str, namespace: &str, body: &Patch, optional: PatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update status of the specified ImageStream
Use the returned k8s_openapi::ResponseBody<k8s_openapi::PatchResponse<Self>> constructor, or k8s_openapi::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the ImageStream
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn read_namespaced_image_stream(
name: &str,
namespace: &str,
optional: ReadNamespacedImageStreamOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedImageStreamResponse>), RequestError>
pub fn read_namespaced_image_stream( name: &str, namespace: &str, optional: ReadNamespacedImageStreamOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedImageStreamResponse>), RequestError>
read the specified ImageStream
Use the returned k8s_openapi::ResponseBody<ReadNamespacedImageStreamResponse> constructor, or ReadNamespacedImageStreamResponse directly, to parse the HTTP response.
Arguments
-
namename of the ImageStream
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn read_namespaced_image_stream_status(
name: &str,
namespace: &str,
optional: ReadNamespacedImageStreamStatusOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedImageStreamStatusResponse>), RequestError>
pub fn read_namespaced_image_stream_status( name: &str, namespace: &str, optional: ReadNamespacedImageStreamStatusOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadNamespacedImageStreamStatusResponse>), RequestError>
read status of the specified ImageStream
Use the returned k8s_openapi::ResponseBody<ReadNamespacedImageStreamStatusResponse> constructor, or ReadNamespacedImageStreamStatusResponse directly, to parse the HTTP response.
Arguments
-
namename of the ImageStream
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn replace_namespaced_image_stream(
name: &str,
namespace: &str,
body: &ImageStream,
optional: ReplaceOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_namespaced_image_stream( name: &str, namespace: &str, body: &ImageStream, optional: ReplaceOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace the specified ImageStream
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ReplaceResponse<Self>> constructor, or k8s_openapi::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the ImageStream
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn replace_namespaced_image_stream_status(
name: &str,
namespace: &str,
body: &ImageStream,
optional: ReplaceOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_namespaced_image_stream_status( name: &str, namespace: &str, body: &ImageStream, optional: ReplaceOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace status of the specified ImageStream
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ReplaceResponse<Self>> constructor, or k8s_openapi::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the ImageStream
-
namespaceobject name and auth scope, such as for teams and projects
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn watch_image_stream_for_all_namespaces(
optional: WatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch_image_stream_for_all_namespaces( optional: WatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind ImageStream
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::WatchResponse<Self>> constructor, or k8s_openapi::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl ImageStream
impl ImageStream
Sourcepub fn watch_namespaced_image_stream(
namespace: &str,
optional: WatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch_namespaced_image_stream( namespace: &str, optional: WatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind ImageStream
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::WatchResponse<Self>> constructor, or k8s_openapi::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namespaceobject name and auth scope, such as for teams and projects
-
optionalOptional parameters. Use
Default::default()to not pass any.