pub struct HostSubnet {
pub egress_cid_rs: Option<Vec<String>>,
pub egress_i_ps: Option<Vec<String>>,
pub host: String,
pub host_ip: String,
pub metadata: ObjectMeta,
pub subnet: String,
}Expand description
HostSubnet describes the container subnet network on a node. The HostSubnet object must have the same name as the Node object it corresponds to.
Fields
egress_cid_rs: Option<Vec<String>>EgressCIDRs is the list of CIDR ranges available for automatically assigning egress IPs to this node from. If this field is set then EgressIPs should be treated as read-only.
egress_i_ps: Option<Vec<String>>EgressIPs is the list of automatic egress IP addresses currently hosted by this node. If EgressCIDRs is empty, this can be set by hand; if EgressCIDRs is set then the master will overwrite the value here with its own allocation of egress IPs.
host: StringHost is the name of the node. (This is the same as the object’s name, but both fields must be set.)
host_ip: StringHostIP is the IP address to be used as a VTEP by other nodes in the overlay network
metadata: ObjectMetaStandard object’s metadata.
subnet: StringSubnet is the CIDR range of the overlay network assigned to the node for its pods
Implementations
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn create_host_subnet(
body: &HostSubnet,
optional: CreateOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
pub fn create_host_subnet( body: &HostSubnet, optional: CreateOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
create a HostSubnet
Use the returned k8s_openapi::ResponseBody<k8s_openapi::CreateResponse<Self>> constructor, or k8s_openapi::CreateResponse<Self> directly, to parse the HTTP response.
Arguments
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn delete_collection_host_subnet(
delete_optional: DeleteOptional<'_>,
list_optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
pub fn delete_collection_host_subnet( delete_optional: DeleteOptional<'_>, list_optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
delete collection of HostSubnet
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<k8s_openapi::List<Self>>> constructor, or k8s_openapi::DeleteResponse<k8s_openapi::List<Self>> directly, to parse the HTTP response.
Arguments
-
delete_optionalDelete options. Use
Default::default()to not pass any. -
list_optionalList options. Use
Default::default()to not pass any.
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn delete_host_subnet(
name: &str,
optional: DeleteOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
pub fn delete_host_subnet( name: &str, optional: DeleteOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
delete a HostSubnet
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<Self>> constructor, or k8s_openapi::DeleteResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the HostSubnet
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn list_host_subnet(
optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list_host_subnet( optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind HostSubnet
This operation only supports listing all items of this type.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ListResponse<Self>> constructor, or k8s_openapi::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn patch_host_subnet(
name: &str,
body: &Patch,
optional: PatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_host_subnet( name: &str, body: &Patch, optional: PatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update the specified HostSubnet
Use the returned k8s_openapi::ResponseBody<k8s_openapi::PatchResponse<Self>> constructor, or k8s_openapi::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the HostSubnet
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn read_host_subnet(
name: &str,
optional: ReadHostSubnetOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadHostSubnetResponse>), RequestError>
pub fn read_host_subnet( name: &str, optional: ReadHostSubnetOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadHostSubnetResponse>), RequestError>
read the specified HostSubnet
Use the returned k8s_openapi::ResponseBody<ReadHostSubnetResponse> constructor, or ReadHostSubnetResponse directly, to parse the HTTP response.
Arguments
-
namename of the HostSubnet
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn replace_host_subnet(
name: &str,
body: &HostSubnet,
optional: ReplaceOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_host_subnet( name: &str, body: &HostSubnet, optional: ReplaceOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace the specified HostSubnet
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ReplaceResponse<Self>> constructor, or k8s_openapi::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the HostSubnet
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl HostSubnet
impl HostSubnet
Sourcepub fn watch_host_subnet(
optional: WatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch_host_subnet( optional: WatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind HostSubnet
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::WatchResponse<Self>> constructor, or k8s_openapi::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.