pub struct OAuthAccessToken {
pub authorize_token: Option<String>,
pub client_name: Option<String>,
pub expires_in: Option<i64>,
pub inactivity_timeout_seconds: Option<i32>,
pub metadata: ObjectMeta,
pub redirect_uri: Option<String>,
pub refresh_token: Option<String>,
pub scopes: Option<Vec<String>>,
pub user_name: Option<String>,
pub user_uid: Option<String>,
}Expand description
OAuthAccessToken describes an OAuth access token
Fields
AuthorizeToken contains the token that authorized this token
client_name: Option<String>ClientName references the client that created this token.
expires_in: Option<i64>ExpiresIn is the seconds from CreationTime before this token expires.
inactivity_timeout_seconds: Option<i32>InactivityTimeoutSeconds is the value in seconds, from the CreationTimestamp, after which this token can no longer be used. The value is automatically incremented when the token is used.
metadata: ObjectMetaStandard object’s metadata.
redirect_uri: Option<String>RedirectURI is the redirection associated with the token.
refresh_token: Option<String>RefreshToken is the value by which this token can be renewed. Can be blank.
scopes: Option<Vec<String>>Scopes is an array of the requested scopes.
user_name: Option<String>UserName is the user name associated with this token
user_uid: Option<String>UserUID is the unique UID associated with this token
Implementations
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn create_o_auth_access_token(
body: &OAuthAccessToken,
optional: CreateOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
pub fn create_o_auth_access_token( body: &OAuthAccessToken, optional: CreateOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
create an OAuthAccessToken
Use the returned k8s_openapi::ResponseBody<k8s_openapi::CreateResponse<Self>> constructor, or k8s_openapi::CreateResponse<Self> directly, to parse the HTTP response.
Arguments
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn delete_collection_o_auth_access_token(
delete_optional: DeleteOptional<'_>,
list_optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
pub fn delete_collection_o_auth_access_token( delete_optional: DeleteOptional<'_>, list_optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
delete collection of OAuthAccessToken
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<k8s_openapi::List<Self>>> constructor, or k8s_openapi::DeleteResponse<k8s_openapi::List<Self>> directly, to parse the HTTP response.
Arguments
-
delete_optionalDelete options. Use
Default::default()to not pass any. -
list_optionalList options. Use
Default::default()to not pass any.
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn delete_o_auth_access_token(
name: &str,
optional: DeleteOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
pub fn delete_o_auth_access_token( name: &str, optional: DeleteOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
delete an OAuthAccessToken
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<Self>> constructor, or k8s_openapi::DeleteResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the OAuthAccessToken
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn list_o_auth_access_token(
optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list_o_auth_access_token( optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind OAuthAccessToken
This operation only supports listing all items of this type.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ListResponse<Self>> constructor, or k8s_openapi::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn patch_o_auth_access_token(
name: &str,
body: &Patch,
optional: PatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_o_auth_access_token( name: &str, body: &Patch, optional: PatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update the specified OAuthAccessToken
Use the returned k8s_openapi::ResponseBody<k8s_openapi::PatchResponse<Self>> constructor, or k8s_openapi::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the OAuthAccessToken
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn read_o_auth_access_token(
name: &str,
optional: ReadOAuthAccessTokenOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadOAuthAccessTokenResponse>), RequestError>
pub fn read_o_auth_access_token( name: &str, optional: ReadOAuthAccessTokenOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadOAuthAccessTokenResponse>), RequestError>
read the specified OAuthAccessToken
Use the returned k8s_openapi::ResponseBody<ReadOAuthAccessTokenResponse> constructor, or ReadOAuthAccessTokenResponse directly, to parse the HTTP response.
Arguments
-
namename of the OAuthAccessToken
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn replace_o_auth_access_token(
name: &str,
body: &OAuthAccessToken,
optional: ReplaceOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_o_auth_access_token( name: &str, body: &OAuthAccessToken, optional: ReplaceOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace the specified OAuthAccessToken
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ReplaceResponse<Self>> constructor, or k8s_openapi::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the OAuthAccessToken
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl OAuthAccessToken
impl OAuthAccessToken
Sourcepub fn watch_o_auth_access_token(
optional: WatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch_o_auth_access_token( optional: WatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind OAuthAccessToken
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::WatchResponse<Self>> constructor, or k8s_openapi::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.