pub struct PodSecurityPolicySubjectReviewStatus {
pub allowed_by: Option<ObjectReference>,
pub reason: Option<String>,
pub template: Option<PodTemplateSpec>,
}Expand description
PodSecurityPolicySubjectReviewStatus contains information/status for PodSecurityPolicySubjectReview.
Fields
allowed_by: Option<ObjectReference>allowedBy is a reference to the rule that allows the PodTemplateSpec. A rule can be a SecurityContextConstraint or a PodSecurityPolicy A nil, indicates that it was denied.
reason: Option<String>A machine-readable description of why this operation is in the “Failure” status. If this value is empty there is no information available.
template: Option<PodTemplateSpec>template is the PodTemplateSpec after the defaulting is applied.