pub struct RangeAllocation {
pub data: ByteString,
pub metadata: ObjectMeta,
pub range: String,
}Expand description
RangeAllocation is used so we can easily expose a RangeAllocation typed for security group
Fields
data: ByteStringdata is a byte array representing the serialized state of a range allocation. It is a bitmap with each bit set to one to represent a range is taken.
metadata: ObjectMetaStandard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
range: Stringrange is a string representing a unique label for a range of uids, “1000000000-2000000000/10000”.
Implementations
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn create_range_allocation(
body: &RangeAllocation,
optional: CreateOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
pub fn create_range_allocation( body: &RangeAllocation, optional: CreateOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<CreateResponse<Self>>), RequestError>
create a RangeAllocation
Use the returned k8s_openapi::ResponseBody<k8s_openapi::CreateResponse<Self>> constructor, or k8s_openapi::CreateResponse<Self> directly, to parse the HTTP response.
Arguments
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn delete_collection_range_allocation(
delete_optional: DeleteOptional<'_>,
list_optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
pub fn delete_collection_range_allocation( delete_optional: DeleteOptional<'_>, list_optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<List<Self>>>), RequestError>
delete collection of RangeAllocation
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<k8s_openapi::List<Self>>> constructor, or k8s_openapi::DeleteResponse<k8s_openapi::List<Self>> directly, to parse the HTTP response.
Arguments
-
delete_optionalDelete options. Use
Default::default()to not pass any. -
list_optionalList options. Use
Default::default()to not pass any.
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn delete_range_allocation(
name: &str,
optional: DeleteOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
pub fn delete_range_allocation( name: &str, optional: DeleteOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<DeleteResponse<Self>>), RequestError>
delete a RangeAllocation
Use the returned k8s_openapi::ResponseBody<k8s_openapi::DeleteResponse<Self>> constructor, or k8s_openapi::DeleteResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the RangeAllocation
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn list_range_allocation(
optional: ListOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
pub fn list_range_allocation( optional: ListOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ListResponse<Self>>), RequestError>
list or watch objects of kind RangeAllocation
This operation only supports listing all items of this type.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ListResponse<Self>> constructor, or k8s_openapi::ListResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn patch_range_allocation(
name: &str,
body: &Patch,
optional: PatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
pub fn patch_range_allocation( name: &str, body: &Patch, optional: PatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<PatchResponse<Self>>), RequestError>
partially update the specified RangeAllocation
Use the returned k8s_openapi::ResponseBody<k8s_openapi::PatchResponse<Self>> constructor, or k8s_openapi::PatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the RangeAllocation
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn read_range_allocation(
name: &str,
optional: ReadRangeAllocationOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadRangeAllocationResponse>), RequestError>
pub fn read_range_allocation( name: &str, optional: ReadRangeAllocationOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReadRangeAllocationResponse>), RequestError>
read the specified RangeAllocation
Use the returned k8s_openapi::ResponseBody<ReadRangeAllocationResponse> constructor, or ReadRangeAllocationResponse directly, to parse the HTTP response.
Arguments
-
namename of the RangeAllocation
-
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn replace_range_allocation(
name: &str,
body: &RangeAllocation,
optional: ReplaceOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
pub fn replace_range_allocation( name: &str, body: &RangeAllocation, optional: ReplaceOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<ReplaceResponse<Self>>), RequestError>
replace the specified RangeAllocation
Use the returned k8s_openapi::ResponseBody<k8s_openapi::ReplaceResponse<Self>> constructor, or k8s_openapi::ReplaceResponse<Self> directly, to parse the HTTP response.
Arguments
-
namename of the RangeAllocation
-
body -
optionalOptional parameters. Use
Default::default()to not pass any.
Sourceimpl RangeAllocation
impl RangeAllocation
Sourcepub fn watch_range_allocation(
optional: WatchOptional<'_>,
) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
pub fn watch_range_allocation( optional: WatchOptional<'_>, ) -> Result<(Request<Vec<u8>>, fn(StatusCode) -> ResponseBody<WatchResponse<Self>>), RequestError>
list or watch objects of kind RangeAllocation
This operation only supports watching one item, or a list of items, of this type for changes.
Use the returned k8s_openapi::ResponseBody<k8s_openapi::WatchResponse<Self>> constructor, or k8s_openapi::WatchResponse<Self> directly, to parse the HTTP response.
Arguments
-
optionalOptional parameters. Use
Default::default()to not pass any.