openshift_if_ge_4_3

Macro openshift_if_ge_4_3 

macro_rules! openshift_if_ge_4_3 {
    ($($tt:tt)*) => { ... };
}
This macro evaluates to its contents if the v4_3 or higher feature is enabled, otherwise it evaluates to nothing.